# MIT License
# Copyright (c) 2023 sikino
# See LICENSE file in the project root for full license information.

import numpy as np
from numpy.typing import NDArray
from typing import Union


class Environment:
    def __init__(
        self,
        fluid_type: str,
        temprature_celsius: Union[float, np.float64],
        pressure_pa: Union[float, np.float64],
        relative_humidity_percent: Union[float, np.float64],
        gravity_m_per_s2: Union[float, np.float64],
        flow_velocity_m_per_s: NDArray[np.float64],
    ):
        self._fluid_type = fluid_type
        self._temprature_celsius = np.float64(temprature_celsius)
        self._pressure_pa = np.float64(pressure_pa)
        self._relative_humidity_percent = np.float64(relative_humidity_percent)
        self._gravity_m_per_s2 = np.float64(gravity_m_per_s2)
        self._flow_velocity_m_per_s = flow_velocity_m_per_s

    @property  # read only
    def fluid_type(self) -> str:
        return self._fluid_type

    @property  # read only
    def temprature_celsius(self) -> np.float64:
        return self._temprature_celsius

    @property  # read only
    def pressure_pa(self) -> np.float64:
        return self._pressure_pa

    @property  # read only
    def relative_humidity_percent(self) -> np.float64:
        return self._relative_humidity_percent

    @property  # read only
    def gravity_m_per_s2(self) -> np.float64:
        return self._gravity_m_per_s2

    @property  # read only
    def flow_velocity_m_per_s(self) -> NDArray[np.float64]:
        return self._flow_velocity_m_per_s
